Yep. Someone didn't bother to check that python-hulahop actually worked, in Ubuntu 9 before uploading it. You'll need to rebuild the python-hulahop package, from source:

    >https://bugs.launchpad.net/ubuntu/+source/sugar-hulahop/+bug/390475
    >
    > Just to be clear I'm running from svn and it works on Ubuntu if you
    > rebuild python-hulahop to get the python 2.6 bindings you don't need
    > to set the python path to xulrunner.

    nice one michael - thank you for investigating.

See the Pyjamas Wiki for contributed information about Pyjamas Desktop and Ubuntu.